
/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/
#include <memory>
#include <QFileInfo>
#include "proteinmatch.h"
#include <pappsomspp/msrun/msrunid.h>

#include "grouping/groupingexperiment.h"

#ifndef IDENTIFICATIONGROUP_H
#define IDENTIFICATIONGROUP_H


class Project;

/** @brief an identification group contains one or more sample to consider for grouping
 */
class IdentificationGroup
{

public:
    IdentificationGroup(Project * project);
    ~IdentificationGroup();

    void addProteinMatch(ProteinMatch * protein_match);
    std::vector<ProteinMatch *> & getProteinMatchList();
    void addMsRunIdSp(pappso::MsRunIdSp ms_run_sp);
    
    
    size_t countValid()const;
    size_t countValidAndChecked()const;


    /** @brief validate or invalidate peptides and proteins based automatic filters and manual checks
     * */
    void updateAutomaticFilters(const AutomaticFilterParameters & automatic_filter_parameters);
private :
    GroupingExperiment * _p_grp_experiment= nullptr;

    Project * _p_project;

    std::vector<ProteinMatch *> _protein_match_list;

    std::vector<pappso::MsRunIdSp> _ms_run_list;
};

#endif // IDENTIFICATIONGROUP_H
