
/*******************************************************************************
* Copyright (c) 2015 Olivier Langella <Olivier.Langella@moulon.inra.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <Olivier.Langella@moulon.inra.fr> - initial API and implementation
******************************************************************************/
#ifndef PROJECT_H
#define PROJECT_H

#include<memory>
#include "identificationgroup.h"
#include "automaticfilterparameters.h"

class Project;
typedef std::shared_ptr<Project> ProjectSp;

class PeptideMatch;
class ProteinMatch;

class Project
{
public:
    Project();
    ~Project();

    ProjectSp makeProjectSp() const;
    void readXpipFile(QFileInfo xpip_source);
    IdentificationGroup* newIdentificationGroup();
    IdentificationGroup* getCurrentIdentificationGroupP() const;

    /** @brief validate or invalidate peptides and proteins based automatic filters and manual checks
     * */
    void updateAutomaticFilters(const AutomaticFilterParameters & automatic_filter_parameters);
 

private :
    std::vector<IdentificationGroup *> _identification_goup_list;
    IdentificationGroup* _p_current_identification_group = nullptr;

    AutomaticFilterParameters _automatic_filter_parameters;
};

#endif // PROJECT_H
